# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# RPM and CPAN versioning works differently
%global cpanver 2.32

# RPM version needs 2 digits after the decimal to preserve upgrade path
%global rpmver	%(echo %{cpanver} | perl -pi -e 's/(.*)/sprintf("%.2f", $1)/e')

Name:		perl-JSON-XS
Summary:	JSON serializing/de-serializing, done correctly and fast
Epoch:		1
Version:	%{rpmver}
Release:	1.%{__distinit}%{__distvers}
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/JSON-XS/
Source0:	http://search.cpan.org/CPAN/authors/id/M/ML/MLEHMANN/JSON-XS-%{cpanver}.tar.gz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	perl(common::sense)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(Test::More)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	perl(common::sense)
# We filter out the upstream versioned provide and use our own for sane RPM dependencies
Provides:	perl(JSON::XS) = %{rpmver}

# Avoid unwanted provides and dependencies (rpm 4.9 onwards)
%{?perl_default_filter}
%global __provides_exclude ^(XS\\.so|perl\\(JSON::XS\\))

%description
This module converts Perl data structures to JSON and vice versa. Its
primary goal is to be correct and its secondary goal is to be fast. To
reach the latter goal it was written in C.

%prep
%setup -q -n JSON-XS-%{cpanver}

# Fix shellbangs
perl -pi -e 's|^#!/opt/bin/perl|#!/usr/bin/perl|' eg/*

# Avoid doc-file dependencies
chmod -c -x eg/*

# Remove redundant unversioned/upstream versioned provide (prior to rpm 4.9)
%if 0%{!?__perllib_provides:1}
%global perl_filt /bin/sh -c "%{__perl_provides} | sed -e '/^perl(JSON::XS)/d'"
%define __perl_provides %{perl_filt}
%endif

%build
perl Makefile.PL INSTALLDIRS=perl OPTIMIZE="%{optflags}"
# Kludge to remove rpaths (needed for distros < FC2)
perl -pi -e 's/^\tLD_RUN_PATH=[^\s]+\s*/\t/' Makefile
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find %{buildroot} -depth -type d -exec rmdir {} ';' 2>/dev/null
chmod -R u+w %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes COPYING README eg/
%{_bindir}/json_xs
%{perl_archlib}/auto/JSON/
%{perl_archlib}/JSON/
%{_mandir}/man1/json_xs.1*
%{_mandir}/man3/JSON::XS.3pm*
%{_mandir}/man3/JSON::XS::Boolean.3pm*

%changelog
* Thu Aug 11 2011 Paul Howarth <paul@city-fan.org> - 1:2.32-1
- update to 2.32:
  - fix a bug in the initial whitespace accumulation

* Wed Jul 27 2011 Paul Howarth <paul@city-fan.org> - 1:2.31-1
- update to 2.31:
  - don't accumulate initial whitespace in the incremental buffer (this can be
    useful to allow whitespace-keepalive on a tcp connection without triggering
    the max_size limit)
  - properly croak on some invalid inputs that are not strings (e.g. undef)
    when trying to decode a JSON text

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 1:2.30-3
- rebuild for perl 5.14.1 in Rawhide
- tweak provides filter not to conflict with new Fedora macros
- nobody else likes macros for commands
- fix dist tag for CentOS 6 and Scientific Linux

* Fri Jan 28 2011 Paul Howarth <paul@city-fan.org> - 1:2.30-2
- import from Fedora

* Mon Oct 11 2010 Marcela Mašláňová <mmaslano@redhat.com> - 1:2.30-1
- update

* Sun May 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 1:2.27-2
- mass rebuild with perl 5.12.0

* Sat Feb 27 2010 Chris Weyl <cweyl@alumni.drew.edu> - 1:2.27-1
- update by Fedora::App::MaintainerTools 0.004
- PERL_INSTALL_ROOT => DESTDIR
- added a new br on perl(common::sense) (version 0)
- added a new req on perl(common::sense) (version 0)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1:2.24-3
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:2.24-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 02 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1:2.24-1
- auto-update to 2.24 (by cpan-spec-update 0.01)

* Thu Mar 26 2009 Chris Weyl <cweyl@alumni.drew.edu> - 2.2311-4
- stripping bad provides of private Perl extension libs

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2311-3
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2311-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 22 2009 Chris Weyl <cweyl@alumni.drew.edu> - 2.2311-1
- update to 2.2311

* Sun Sep 07 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.2222-1
- update to the increasingly silly version of 2.2222
- update files to include bin

* Wed Jun 25 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.21-1
- update to 2.21

* Wed May 28 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.2-1
- update to 2.2

* Sun Mar 09 2008 Chris Weyl <cweyl@alumni.drew.edu> - 2.01-1
- update to 2.x series before F9

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.52-3
- rebuild for new perl

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.52-2
- autorebuild for GCC 4.3

* Wed Oct 17 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.52-1
- update to 1.52
- license tag update: GPL -> GPL+

* Tue Aug 21 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.43-2
- bump

* Thu Aug 09 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.43-1
- update to 1.43

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.22-1
- update to 1.22

* Mon May 14 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.21-3
- bump

* Mon May 14 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.21-2
- add eg/ to doc

* Sun May 13 2007 Chris Weyl <cweyl@alumni.drew.edu> 1.21-1
- specfile autogenerated by cpanspec 1.71
